==> library1.4.1.tar.bz2: library/printform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "utils/chlang_osn.php";

  $title = $TEXT['menu-btn33-title'];
  $button = $TEXT['menu-btn33-3'];
  $action = "print.php";

?>
<script type="text/javascript" language="JavaScript" src="lang/<?php echo $lang; ?>/calendar_usr.js"></script>
<?php
require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top.php";

if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}
?>
<form name='book' enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" width="60%" border="0">
<tr>
<td>
<fieldset>
    <legend align="left" title="<?php echo $TEXT['menu-btn33']; ?>"><?php echo $TEXT['menu-btn33-title2']; ?></legend>
<table align="right" width="100%" border="0">
<tr><td class="inform"><?php echo $TEXT['book-data']; ?>:</td><td><input size=4 maxlength=4 type=text name=data_izdaniya /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-data2']; ?>:</td><td><input size=10 maxlength=10 type=text name=data_postupleniya />
<script type="text/javascript" language="JavaScript">
	var o_cal = new tcal ({
		// form name
		'formname': 'book',
		// input name
		'controlname': 'data_postupleniya'
	});
	</script></td></tr>
<tr><td class="inform"><?php echo $TEXT['login-fullname']; ?>:</td><td>
    <select name="login_id">
    <?php
        $querylgn = "SELECT login_id, name, familiya, otchestvo FROM `tbl_logins` ORDER BY familiya, name, otchestvo ";
          $resultlgn = mysqli_query($dbcnx,$querylgn);
            if(!$resultlgn) {puterror2($result2['skin'],$TEXT['error-tbl7']); require_once "utils/bottom.php"; exit();}
              while($result_login = mysqli_fetch_array($resultlgn))
                {
                 $chk_login = "<option value=".$result_login['login_id'].">".$result_login['familiya']." ".$result_login['name']." ".$result_login['otchestvo']."";
                 echo $chk_login;
                }
    ?>
    </select><input type=checkbox name=login_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['aut-full']; ?>:</td><td>
    <select name="autor_id">
    <?php
        $queryaut = "SELECT autor_id, name, familiya, otchestvo FROM `tbl_autor` ORDER BY name, familiya, otchestvo ";
          $resultaut = mysqli_query($dbcnx,$queryaut);
            if(!$resultaut) {puterror2($result2['skin'],$TEXT['error-tbl1']); require_once "utils/bottom.php"; exit();}
              while($result_autor = mysqli_fetch_array($resultaut))
                {
                 $chk_autor = "<option value=".$result_autor['autor_id'].">".$result_autor['name']." ".$result_autor['otchestvo']." ".$result_autor['familiya']."";
                 echo $chk_autor;
                }
    ?>
    </select><input type=checkbox name=autor_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-izd']; ?>:</td><td>
    <select name="izd_id">
    <?php
        $queryizd = "SELECT izd_id, izdatelstvo FROM `tbl_izdatelstvo` ORDER BY `izdatelstvo` ";
          $resultizd = mysqli_query($dbcnx,$queryizd);
            if(!$resultizd) {puterror2($result2['skin'],$TEXT['error-tbl6']); require_once "utils/bottom.php"; exit();}
              while($result_izdatelstvo = mysqli_fetch_array($resultizd))
                {
                 $chk_izdatelstvo = "<option value=".$result_izdatelstvo['izd_id'].">".$result_izdatelstvo['izdatelstvo']."";
                 echo $chk_izdatelstvo;
                }
    ?>
    </select><input type=checkbox name=izd_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['ser-title']; ?>:</td><td>
    <select name="ser_id">
    <?php
        $queryser = "SELECT * FROM `tbl_seriya` ORDER BY `seriya` ";
          $resultser = mysqli_query($dbcnx,$queryser);
            if(!$resultser) {puterror2($result2['skin'],$TEXT['error-tbl21']); require_once "utils/bottom.php"; exit();}
              while($result_seriya = mysqli_fetch_array($resultser))
                {
                 $chk_seriya = "<option value=".$result_seriya['ser_id'].">".$result_seriya['seriya']."";
                 echo $chk_seriya;
                }
    ?>
    </select><input type=checkbox name=ser_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-zhanr']; ?>:</td><td>
    <select name="zhanr_id">
    <?php
        $query10 = "SELECT * FROM `tbl_zhanr`ORDER BY `zhanr` ";
          $result10 = mysqli_query($dbcnx,$query10);
            if(!$result10) {puterror2($result2['skin'],$TEXT['error-tbl14']); require_once "utils/bottom.php"; exit();}
              while($result_zhanr = mysqli_fetch_array($result10))
                {
                 $chk_zhanr = "<option value=".$result_zhanr['zhanr_id'].">".$result_zhanr['zhanr']."";
                 echo $chk_zhanr;
                }
    ?>
    </select><input type=checkbox name=zhanr_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-cicle']; ?>:</td><td>
    <select name="cicle_id">
    <?php
        $query11 = "SELECT * FROM `tbl_cicle` ORDER BY `cicle` ";
          $result11 = mysqli_query($dbcnx,$query11);
            if(!$result11) {puterror2($result2['skin'],$TEXT['error-tbl5']); require_once "utils/bottom.php"; exit();}
              while($result_cicle = mysqli_fetch_array($result11))
                {
                 $chk_cicle = "<option value=".$result_cicle['cicle_id'].">".$result_cicle['cicle']."";
                 echo $chk_cicle;
                }
    ?>
    </select><input type=checkbox name=cicle_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-tip-izd']; ?>:</td><td>
    <select name="tip_izd_id">
    <?php
        $query12 = "SELECT * FROM `tbl_tip_izd` ORDER BY `tip_izd` ";
          $result12 = mysqli_query($dbcnx,$query12);
            if(!$result12) {puterror2($result2['skin'],$TEXT['error-tbl15']); require_once "utils/bottom.php"; exit();}
              while($result_izd = mysqli_fetch_array($result12))
                {
                 $chk_izd = "<option value=".$result_izd['tip_izd_id'].">".$result_izd['tip_izd']."";
                 echo $chk_izd;
                }
    ?>
    </select><input type=checkbox name=tip_izd_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-bibl']; ?>:</td><td>
    <select name="bibl_id">
    <?php
        $query13 = "SELECT name, bibl_id FROM `tbl_biblioteka` ORDER BY `name` ";
          $result13 = mysqli_query($dbcnx,$query13);
            if(!$result13) {puterror2($result2['skin'],$TEXT['error-tbl2']); require_once "utils/bottom.php"; exit();}
              while($result_libr = mysqli_fetch_array($result13))
                {
                 $chk_libr = "<option value=".$result_libr['bibl_id'].">".$result_libr['name']."";
                 echo $chk_libr;
                }
    ?>
    </select><input type=checkbox name=bibl_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-zal']; ?>:</td><td>
    <select name="zal_id">
    <?php
        $query14 = "SELECT * FROM `tbl_zal` ORDER BY `zal` ";
          $result14 = mysqli_query($dbcnx,$query14);
            if(!$result14) {puterror2($result2['skin'],$TEXT['error-tbl11']); require_once "utils/bottom.php"; exit();}
              while($result_zal = mysqli_fetch_array($result14))
                {
                 $chk_zal = "<option value=".$result_zal['zal_id'].">".$result_zal['zal']."";
                 echo $chk_zal;
                }
    ?>
    </select><input type=checkbox name=zal_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-shkaf']; ?>:</td><td>
    <select name="shkaf_id">
    <?php
        $query15 = "SELECT * FROM `tbl_shkaf` ORDER BY `shkaf` ";
          $result15 = mysqli_query($dbcnx,$query15);
            if(!$result15) {puterror2($result2['skin'],$TEXT['error-tbl9']); require_once "utils/bottom.php"; exit();}
              while($result_shkaf = mysqli_fetch_array($result15))
                {
                 $chk_shkaf = "<option value=".$result_shkaf['shkaf_id'].">".$result_shkaf['shkaf']."";
                 echo $chk_shkaf;
                }
    ?>
    </select><input type=checkbox name=shkaf_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-polka']; ?>:</td><td>
    <select name="polka_id">
    <?php
        $query16 = "SELECT * FROM `tbl_polka` ORDER BY `polka` ";
          $result16 = mysqli_query($dbcnx,$query16);
            if(!$result16) {puterror2($result2['skin'],$TEXT['error-tbl8']); require_once "utils/bottom.php"; exit();}
              while($result_polka = mysqli_fetch_array($result16))
                {
                 $chk_polka = "<option value=".$result_polka['polka_id'].">".$result_polka['polka']."";
                 echo $chk_polka;
                }
    ?>
    </select><input type=checkbox name=polka_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['menu-btn35']; ?>:</td><td>
    <select name="bl_id">
    <?php
        $query17 = "SELECT `bl_id`,`booklang` FROM `tbl_booklang` ORDER BY `position`, `booklang` ";
          $result17 = mysqli_query($dbcnx,$query17);
            if (!$result17) {puterror($result2['skin'],$TEXT['error-tbl23']); require_once "../utils/bottom_adm.php"; exit();}
              while($result_bl = mysqli_fetch_array($result17))
                {
                 $chk_bl = "<option value=".$result_bl['bl_id'].">".$result_bl['booklang']."";
                 echo $chk_bl;
                }
    ?>
    </select><input type=checkbox name=bl_ch /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-vidano']; ?>:</td><td><input type=radio name=vidano value=1></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-show4']; ?>:</td><td><input type=radio name=vidano value=2></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-show5']; ?>:</td><td><input type=radio name=vidano value=3></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-oglavl2']; ?>:</td><td><input type=checkbox name=oglavlenie /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-org-viv']; ?>:</td><td><input type=checkbox name=org_viv /></td></tr>
</table>
</fieldset>
</td></tr>
<tr><td><input type=submit value='<?php echo $button; ?>' /></td></tr>
</table>
</form>
<?php
  require_once "utils/bottom.php";
?>

==> library1.19.1.tar.bz2: library/printform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  require_once "utils/chlang_osn.php";

  $title = $TEXT['menu-btn33-title'];
  $button = $TEXT['menu-btn33-3'];
  $action = "print.php";

?>
<script type="text/javascript" language="JavaScript" src="lang/<?php echo $lang; ?>/calendar_usr.js"></script>
<?php
require_once "config.php";
require_once "utils/functions.php";
require_once "utils/top.php";

if($result2['administrator'] == 0 && $result2['user'] == 0) {puterror2($result2['skin'],$TEXT['error-loginform2']); require_once "utils/bottom.php"; exit();}
?>
<form name="book" enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center" width="60%" border="0">
<tr>
<td>
<fieldset>
    <legend align="left" title="<?php echo $TEXT['menu-btn33']; ?>"><?php echo $TEXT['menu-btn33-title2']; ?></legend>
<table align="right" width="100%" border="0">
<tr><td class="inform"><?php echo $TEXT['book-data']; ?>:</td><td><input size="4" maxlength="4" type="text" name="data_izdaniya" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-data2']; ?>:</td><td><input size="10" maxlength="10" type="text" name="data_postupleniya" />
<script type="text/javascript" language="JavaScript">
	var o_cal = new tcal ({
		// form name
		'formname': 'book',
		// input name
		'controlname': 'data_postupleniya'
	});
	</script></td></tr>
<tr><td class="inform"><?php echo $TEXT['login-fullname']; ?>:</td><td>
    <select name="login_id">
    <?php
        $querylgn = "SELECT login_id, name, familiya, otchestvo FROM `tbl_logins` ORDER BY familiya, name, otchestvo ";
          $resultlgn = mysqli_query($dbcnx,$querylgn);
            if(!$resultlgn) {puterror2($result2['skin'],$TEXT['error-tbl7']); require_once "utils/bottom.php"; exit();}
              while($result_login = mysqli_fetch_array($resultlgn))
                {
                 $chk_login = "<option value=".$result_login['login_id'].">".rep_back($result_login['familiya'])." ".rep_back($result_login['name'])." ".rep_back($result_login['otchestvo'])."";
                 echo $chk_login;
                }
    ?>
    </select><input type="checkbox" name="login_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['aut-full']; ?>:</td><td>
    <select name="autor_id">
    <?php
        $queryaut = "SELECT autor_id, name, familiya, otchestvo FROM `tbl_autor` ORDER BY name, familiya, otchestvo ";
          $resultaut = mysqli_query($dbcnx,$queryaut);
            if(!$resultaut) {puterror2($result2['skin'],$TEXT['error-tbl1']); require_once "utils/bottom.php"; exit();}
              while($result_autor = mysqli_fetch_array($resultaut))
                {
                 $chk_autor = "<option value=".$result_autor['autor_id'].">".rep_back($result_autor['name'])." ".rep_back($result_autor['otchestvo'])." ".rep_back($result_autor['familiya'])."";
                 echo $chk_autor;
                }
    ?>
    </select><input type="checkbox" name="autor_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-izd']; ?>:</td><td>
    <select name="izd_id">
    <?php
        $queryizd = "SELECT izd_id, izdatelstvo FROM `tbl_izdatelstvo` ORDER BY `izdatelstvo` ";
          $resultizd = mysqli_query($dbcnx,$queryizd);
            if(!$resultizd) {puterror2($result2['skin'],$TEXT['error-tbl6']); require_once "utils/bottom.php"; exit();}
              while($result_izdatelstvo = mysqli_fetch_array($resultizd))
                {
                 $chk_izdatelstvo = "<option value=".$result_izdatelstvo['izd_id'].">".rep_back($result_izdatelstvo['izdatelstvo']."");
                 echo $chk_izdatelstvo;
                }
    ?>
    </select><input type="checkbox" name="izd_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['ser-title']; ?>:</td><td>
    <select name="ser_id">
    <?php
        $queryser = "SELECT * FROM `tbl_seriya` ORDER BY `seriya` ";
          $resultser = mysqli_query($dbcnx,$queryser);
            if(!$resultser) {puterror2($result2['skin'],$TEXT['error-tbl21']); require_once "utils/bottom.php"; exit();}
              while($result_seriya = mysqli_fetch_array($resultser))
                {
                 $chk_seriya = "<option value=".$result_seriya['ser_id'].">".rep_back($result_seriya['seriya']."");
                 echo $chk_seriya;
                }
    ?>
    </select><input type="checkbox" name="ser_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-zhanr']; ?>:</td><td>
    <select name="zhanr_id">
    <?php
        $query10 = "SELECT * FROM `tbl_zhanr`ORDER BY `zhanr` ";
          $result10 = mysqli_query($dbcnx,$query10);
            if(!$result10) {puterror2($result2['skin'],$TEXT['error-tbl14']); require_once "utils/bottom.php"; exit();}
              while($result_zhanr = mysqli_fetch_array($result10))
                {
                 $chk_zhanr = "<option value=".$result_zhanr['zhanr_id'].">".rep_back($result_zhanr['zhanr']."");
                 echo $chk_zhanr;
                }
    ?>
    </select><input type="checkbox" name="zhanr_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-cicle']; ?>:</td><td>
    <select name="cicle_id">
    <?php
        $query11 = "SELECT * FROM `tbl_cicle` ORDER BY `cicle` ";
          $result11 = mysqli_query($dbcnx,$query11);
            if(!$result11) {puterror2($result2['skin'],$TEXT['error-tbl5']); require_once "utils/bottom.php"; exit();}
              while($result_cicle = mysqli_fetch_array($result11))
                {
                 $chk_cicle = "<option value=".$result_cicle['cicle_id'].">".rep_back($result_cicle['cicle']."");
                 echo $chk_cicle;
                }
    ?>
    </select><input type="checkbox" name="cicle_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-tip-izd']; ?>:</td><td>
    <select name="tip_izd_id">
    <?php
        $query12 = "SELECT * FROM `tbl_tip_izd` ORDER BY `tip_izd` ";
          $result12 = mysqli_query($dbcnx,$query12);
            if(!$result12) {puterror2($result2['skin'],$TEXT['error-tbl15']); require_once "utils/bottom.php"; exit();}
              while($result_izd = mysqli_fetch_array($result12))
                {
                 $chk_izd = "<option value=".$result_izd['tip_izd_id'].">".rep_back($result_izd['tip_izd']."");
                 echo $chk_izd;
                }
    ?>
    </select><input type="checkbox" name="tip_izd_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-bibl']; ?>:</td><td>
    <select name="bibl_id">
    <?php
        $query13 = "SELECT name, bibl_id FROM `tbl_biblioteka` ORDER BY `name` ";
          $result13 = mysqli_query($dbcnx,$query13);
            if(!$result13) {puterror2($result2['skin'],$TEXT['error-tbl2']); require_once "utils/bottom.php"; exit();}
              while($result_libr = mysqli_fetch_array($result13))
                {
                 $chk_libr = "<option value=".$result_libr['bibl_id'].">".rep_back($result_libr['name']."");
                 echo $chk_libr;
                }
    ?>
    </select><input type="checkbox" name="bibl_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-zal']; ?>:</td><td>
    <select name="zal_id">
    <?php
        $query14 = "SELECT * FROM `tbl_zal` ORDER BY `zal` ";
          $result14 = mysqli_query($dbcnx,$query14);
            if(!$result14) {puterror2($result2['skin'],$TEXT['error-tbl11']); require_once "utils/bottom.php"; exit();}
              while($result_zal = mysqli_fetch_array($result14))
                {
                 $chk_zal = "<option value=".$result_zal['zal_id'].">".rep_back($result_zal['zal']."");
                 echo $chk_zal;
                }
    ?>
    </select><input type="checkbox" name="zal_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-shkaf']; ?>:</td><td>
    <select name="shkaf_id">
    <?php
        $query15 = "SELECT * FROM `tbl_shkaf` ORDER BY `shkaf` ";
          $result15 = mysqli_query($dbcnx,$query15);
            if(!$result15) {puterror2($result2['skin'],$TEXT['error-tbl9']); require_once "utils/bottom.php"; exit();}
              while($result_shkaf = mysqli_fetch_array($result15))
                {
                 $chk_shkaf = "<option value=".$result_shkaf['shkaf_id'].">".rep_back($result_shkaf['shkaf']."");
                 echo $chk_shkaf;
                }
    ?>
    </select><input type="checkbox" name="shkaf_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-polka']; ?>:</td><td>
    <select name="polka_id">
    <?php
        $query16 = "SELECT * FROM `tbl_polka` ORDER BY `polka` ";
          $result16 = mysqli_query($dbcnx,$query16);
            if(!$result16) {puterror2($result2['skin'],$TEXT['error-tbl8']); require_once "utils/bottom.php"; exit();}
              while($result_polka = mysqli_fetch_array($result16))
                {
                 $chk_polka = "<option value=".$result_polka['polka_id'].">".rep_back($result_polka['polka']."");
                 echo $chk_polka;
                }
    ?>
    </select><input type="checkbox" name="polka_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['menu-btn35']; ?>:</td><td>
    <select name="bl_id">
    <?php
        $query17 = "SELECT `bl_id`, `position`, `booklang` FROM `tbl_booklang` ORDER BY `position`, `booklang` ";
          $result17 = mysqli_query($dbcnx,$query17);
            if (!$result17) {puterror($result2['skin'],$TEXT['error-tbl23']); require_once "../utils/bottom_adm.php"; exit();}
              while($result_bl = mysqli_fetch_array($result17))
                {
                 $chk_bl = "<option value=".$result_bl['bl_id'].">".rep_back($result_bl['booklang']."");
                 echo $chk_bl;
                }
    ?>
    </select><input type="checkbox" name="bl_ch" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-vidano']; ?>:</td><td><input type="radio" name="vidano" value="1"></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-show4']; ?>:</td><td><input type="radio" name="vidano" value="2"></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-show5']; ?>:</td><td><input type="radio" name="vidano" value="3"></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-oglavl2']; ?>:</td><td><input type="checkbox" name="oglavlenie" /></td></tr>
<tr><td class="inform"><?php echo $TEXT['book-org-viv']; ?>:</td><td><input type="checkbox" name="org_viv" /></td></tr>
</table>
</fieldset>
</td></tr>
<tr><td><input type="submit" value="<?php echo $button; ?>" /></td></tr>
</table>
</form>
<?php
  require_once "utils/bottom.php";
?>
